@@ -437,15 +437,17 @@ class BL3Profile(object):
 
     def get_char_skins_total(self):
         """
-        Returns the total number of skins that are possible to unlock
+        Returns the total number of skins that are possible to unlock.  Includes the
+        skins that are unlocked by default (just one per char).
         """
-        return len(profile_skins)
+        return len(profile_skins) + len(profile_skins_defaults)
 
     def get_char_skins(self):
         """
-        Returns a set of the current character skins which are unlocked.
+        Returns a set of the current character skins which are unlocked.  Includes the
+        skins that are unlocked by default (just one per char).
         """
-        return self.get_cur_customizations(profile_skins)
+        return self.get_cur_customizations(profile_skins) | profile_skins_defaults
 
     def unlock_char_skins(self):
         """
@@ -455,15 +457,17 @@ class BL3Profile(object):
 
     def get_char_heads_total(self):
         """
-        Returns the total number of heads that are possible to unlock
+        Returns the total number of heads that are possible to unlock.  Includes the
+        heads that are unlocked by default (just one per char).
         """
-        return len(profile_heads)
+        return len(profile_heads) + len(profile_heads_defaults)
 
     def get_char_heads(self):
         """
-        Returns a set of the current character heads which are unlocked.
+        Returns a set of the current character heads which are unlocked.  Includes the
+        heads that are unlocked by default (just one per char).
         """
-        return self.get_cur_customizations(profile_heads)
+        return self.get_cur_customizations(profile_heads) | profile_heads_defaults
 
     def unlock_char_heads(self):
         """
@@ -473,15 +477,17 @@ class BL3Profile(object):
 
     def get_echo_themes_total(self):
         """
-        Returns the total number of ECHO themes that are possible to unlock
+        Returns the total number of ECHO themes that are possible to unlock.  Includes
+        the ECHO theme that is unlocked by default.
         """
-        return len(profile_echothemes)
+        return len(profile_echothemes) + len(profile_echothemes_defaults)
 
     def get_echo_themes(self):
         """
-        Returns a set of the current ECHO themes which are unlocked.
+        Returns a set of the current ECHO themes which are unlocked.  Includes the
+        ECHO theme that is unlocked by default.
         """
-        return self.get_cur_customizations(profile_echothemes)
+        return self.get_cur_customizations(profile_echothemes) | profile_echothemes_defaults
 
     def unlock_echo_themes(self):
         """
@@ -491,15 +497,17 @@ class BL3Profile(object):
 
     def get_emotes_total(self):
         """
-        Returns the total number of emotes that are possible to unlock
+        Returns the total number of emotes that are possible to unlock.  Includes the
+        emotes that are unlocked by default (four per char).
         """
-        return len(profile_emotes)
+        return len(profile_emotes) + len(profile_emotes_defaults)
 
     def get_emotes(self):
         """
-        Returns a set of the current emotes which are unlocked.
+        Returns a set of the current emotes which are unlocked.  Includes the emotes
+        that are unlocked by default (four per char).
         """
-        return self.get_cur_customizations(profile_emotes)
+        return self.get_cur_customizations(profile_emotes) | profile_emotes_defaults
 
     def unlock_emotes(self):
         """
@@ -509,7 +517,7 @@ class BL3Profile(object):
 
     def get_room_decos_total(self):
         """
-        Returns the total number of room decorations that are possible to unlock
+        Returns the total number of room decorations that are possible to unlock.
         """
         return len(profile_roomdeco_obj_to_eng)
 
@@ -603,7 +611,7 @@ class BL3Profile(object):
         for d in self.prof.unlocked_crew_quarters_decorations:
             cur_decos[d.decoration_item_asset_path] = d.is_new
         new_order = []
-        for name, obj_path in sorted(profile_roomdeco_eng_to_obj.items()):
+        for name, obj_path in sorted(profile_roomdeco_eng_to_obj.items(), key=lambda i: i[0].casefold()):
             if obj_path in cur_decos:
                 new_order.append((obj_path, cur_decos[obj_path]))
                 del cur_decos[obj_path]
@@ -623,11 +631,11 @@ class BL3Profile(object):
         for c in self.prof.unlocked_inventory_customization_parts:
             cur_custs[c.customization_part_hash] = c.is_new
         new_order = []
-        for name, hashval in sorted(profile_weaponskins_eng_to_hash.items()):
+        for name, hashval in sorted(profile_weaponskins_eng_to_hash.items(), key=lambda i: i[0].casefold()):
             if hashval in cur_custs:
                 new_order.append((hashval, cur_custs[hashval]))
                 del cur_custs[hashval]
-        for name, hashval in sorted(profile_weapontrinkets_eng_to_hash.items()):
+        for name, hashval in sorted(profile_weapontrinkets_eng_to_hash.items(), key=lambda i: i[0].casefold()):
             if hashval in cur_custs:
                 new_order.append((hashval, cur_custs[hashval]))
                 del cur_custs[hashval]
@@ -641,3 +649,27 @@ class BL3Profile(object):
                 is_new=is_new,
                 ))
 
+    def get_golden_keys(self):
+        """
+        Returns the number of golden keys stored on this profile
+        """
+        for cat in self.prof.bank_inventory_category_list:
+            if cat.base_category_definition_hash == goldenkey_hash:
+                return cat.quantity
+        return 0
+
+    def set_golden_keys(self, num_keys):
+        """
+        Sets the number of golden keys to `num_keys`
+        """
+        for cat in self.prof.bank_inventory_category_list:
+            if cat.base_category_definition_hash == goldenkey_hash:
+                cat.quantity = num_keys
+                return
+
+        # If we got here, apparently this profile hasn't seen golden keys at all
+        self.prof.bank_inventory_category_list.append(OakShared_pb2.InventoryCategorySaveData(
+            base_category_definition_hash=goldenkey_hash,
+            quantity=num_keys
+            ))
+
